@@ -163,8 +163,16 @@ class JSONFilter:
 
     @property
     def contains(self):
-        return cp.AlwaysTrue() if self._driver is Driver.SQLITE else cp.JSONContains()
+        return (
+            cp.AlwaysTrue()
+            if self._driver is Driver.SQLITE
+            else cp.JSONContains()
+        )
 
     @property
     def empty(self):
-        return cp.AlwaysTrue() if self._driver is Driver.SQLITE else cp.EmptyJson()
+        return (
+            cp.AlwaysTrue()
+            if self._driver is Driver.SQLITE
+            else cp.EmptyJson()
+        )
