@@ -1,6 +1,12 @@
 from .base import setup_database
 from .connection import ConnectionProvider
-from .session import SessionProvider
 from .context import connection_factory, session_factory
+from .session import SessionProvider
 
-__all__ = ['ConnectionProvider', 'SessionProvider', 'setup_database', 'connection_factory', 'session_factory']
+__all__ = [
+    'ConnectionProvider',
+    'SessionProvider',
+    'setup_database',
+    'connection_factory',
+    'session_factory',
+]
